@@ -89,7 +89,7 @@ static const char imonths[] = {
  * Returns: the first string pointer from those provided which
  * matches, otherwise %NULL.
  *
- * Since: 0.9
+ * Since: 0.10
  **/
 const gchar *
 tracker_coalesce_strip (gint n_values,
@@ -180,7 +180,7 @@ tracker_coalesce (gint n_values,
  * Returns: a newly-allocated string holding the result which should
  * be freed with g_free() when finished with, otherwise %NULL.
  *
- * Since: 0.9
+ * Since: 0.10
  **/
 gchar *
 tracker_merge_const (const gchar *delimiter,
@@ -371,7 +371,7 @@ tracker_text_normalize (const gchar *text,
  *
  * Returns: %TRUE if some bytes were found to be valid, %FALSE otherwise.
  *
- * Since: 0.9
+ * Since: 0.10
  **/
 gboolean
 tracker_text_validate_utf8 (const gchar  *text,
@@ -440,10 +440,29 @@ tracker_date_format_to_iso8601 (const gchar *date_string,
 		return NULL;
 	}
 
+	/* If the input format string doesn't parse timezone information with
+	 * either %z or %Z, strptime() won't set the tm_gmtoff member in the
+	 * broken-down time, and the value during initialization (0) will be
+	 * left. This effectively means that every broken-down time obtained
+	 * with strptime() without parsing timezone information will be based
+	 * on UTC, instead of being treated as localtime. In order to fix this
+	 * and set the correct value for the offset w.r.t gmt, we can just
+	 * use mktime() to fill in the daylight saving flag as well as the
+	 * gmt offset value. */
+	if (!strstr (format, "%z") && !strstr (format, "%Z")) {
+		/* tm_isdst not set by strptime(), we set -1 on it in order to ask
+		 * mktime to 'normalize' its contents and fill in the gmt offset
+		 * and daylight saving time information */
+		date_tm.tm_isdst = -1;
+
+		/* Note: no real problem if mktime() fails. In this case, tm_isdst
+		 * will be -1, and therefore strftime() will not write the timezone
+		 * information, which is equally right to represent localtime. */
+		mktime (&date_tm);
+	}
+
 	result = g_malloc (sizeof (char) * 25);
-
 	strftime (result, 25, DATE_FORMAT_ISO8601 , &date_tm);
-
 	return result;
 }
 
@@ -907,7 +926,7 @@ my_igetdelim (gchar  **linebuf,
  * can be used to handle embedded %NULL bytes in the line read. Upon
  * failure, -1 is returned.
  *
- * Since: 0.9
+ * Since: 0.10
  **/
 gssize
 tracker_getline (gchar **lineptr,
@@ -936,7 +955,7 @@ tracker_getline (gchar **lineptr,
  * can be used to handle embedded %NULL bytes in the line read. Upon
  * failure, -1 is returned.
  *
- * Since: 0.9
+ * Since: 0.10
  **/
 gssize
 tracker_getline (gchar **lineptr,
@@ -957,16 +976,17 @@ tracker_getline (gchar **lineptr,
  * Parses a keywords line into store, avoiding duplicates and stripping leading
  * and trailing spaces from keywords. Allowed delimiters are , and ;
  *
- * Since: 0.9
+ * Since: 0.10
  **/
 void
 tracker_keywords_parse (GPtrArray   *store,
                         const gchar *keywords)
 {
-	gchar *keywords_d = g_strdup (keywords);
+	gchar *orig, *keywords_d;
 	char *saveptr, *p;
 	size_t len;
 
+	keywords_d = orig = g_strdup (keywords);
 	p = keywords_d;
 	keywords_d = strchr (keywords_d, '"');
 
@@ -1010,5 +1030,5 @@ tracker_keywords_parse (GPtrArray   *store,
 		g_free (p_do);
 	}
 
-	g_free (keywords_d);
+	g_free (orig);
 }
